==> haskell-th-extras-0.0.0.4-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-extras
version:              0.0.0.4
visibility:           public
id:                   th-extras-0.0.0.4-2swt8ZDEz0C2kFsZfixN6J
key:                  th-extras-0.0.0.4-2swt8ZDEz0C2kFsZfixN6J
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/mokus0/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  4916ad69ab0ebf7ae8460c37eb8dbe51
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-extras-0.0.0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-extras-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-extras-0.0.0.4
hs-libraries:         HSth-extras-0.0.0.4-2swt8ZDEz0C2kFsZfixN6J
depends:
    base-4.15.0.0 containers-0.6.4.1 syb-0.7.2.1-JJZ7ElOKhr6qvmtx8wPbK
    template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-DBpnRpG8EZgFebz88L1kOA

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-extras-0.0.0.4-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-extras
version:              0.0.0.4
visibility:           public
id:                   th-extras-0.0.0.4-CAmJz35LSGE5NDFu3eXXA
key:                  th-extras-0.0.0.4-CAmJz35LSGE5NDFu3eXXA
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/mokus0/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  5b66d85fb8db1b2847616cac23fe75a0
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-extras-0.0.0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-extras-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-extras-0.0.0.4
hs-libraries:         HSth-extras-0.0.0.4-CAmJz35LSGE5NDFu3eXXA
depends:
    base-4.15.0.0 containers-0.6.4.1 syb-0.7.2.1-1a6c6zHMv9nII8iZ0MCvXA
    template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-DBpnRpG8EZgFebz88L1kOA

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
